# Tanjun

A flexible command framework designed to extend Hikari.

# Instillation

You can install Tanjun from PyPI using the following command.

```
python -m pip install hikari-tanjun -U
```

# Quick Usage.

For usage see the the [documentation](https://fasterspeeding.github.io/Tanjun/)
and the [examples](https://github.com/FasterSpeeding/Tanjun/tree/master/examples).

